.. _contributing:

Contributing
============

Every open source project lives from the generous help by contributors
that sacrifice their time and nibada is no different.

Here are a few hints and rules to get you started:

-  No contribution is too small; please submit as many fixes for typos
   and grammar bloopers as you can!
-  Don’t *ever* break backward compatibility.
-  *Always* add tests and docs for your code.
-  This is a hard rule; patches with missing tests or documentation
   won’t be merged. If a feature is not tested or documented, it doesn’t
   exist.
-  Obey `PEP8 <http://www.python.org/dev/peps/pep-0008/>`__ and
   `PEP257 <http://www.python.org/dev/peps/pep-0257/>`__.
-  Write good commit messages.
-  Ideally,
   `squash <http://gitready.com/advanced/2009/02/10/squashing-commits-with-rebase.html>`__
   your commits, i.e. make your pull requests just one commit.
-  If you're not comfortable with using git, please use git format-patch
   and send me the resulting diff.

If you have something great but aren’t sure whether it adheres -- or
even can adhere -- to the rules above: **please submit a pull request
anyway**!

In the best case, we can mold it into something, in the worst case the
pull request gets politely closed. There’s absolutely nothing to fear.

Thank you for considering to contribute to nibada! If you have any
question or concerns, feel free to reach out to us.
